==> openGion_core_5.8.4.0.zip: ge/db/oracle/sql/install/01_TABLE/GE33S.sql <==
/****************************************************************************/
/* GE33 ( ｸﾞﾙｰﾌﾟﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2014/12/16 09:05:41                                            */
/****************************************************************************/
CREATE TABLE GE33 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , GROUP_ID     VARCHAR2 (  20 )                    NOT NULL            /*  20 ｸﾞﾙｰﾌﾟID */
 , ADDRESS      VARCHAR2 ( 256 )                    NOT NULL            /*  30 ｱﾄﾞﾚｽ    */
 , NAME_JA      VARCHAR2 ( 200 )                                        /*  40 名称     */
 , KBNAME       VARCHAR2 (   1 )                    NOT NULL            /*  50 名称区分 */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員 */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

CREATE SEQUENCE GE33S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GE33T00 
  BEFORE INSERT ON GE33
  FOR EACH ROW 
  BEGIN 
    SELECT GE33S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion_core_5.9.20.0.zip: ge/db/oracle/sql/install/01_TABLE/GE33S.sql <==
/****************************************************************************/
/* GE33 ( ｸﾞﾙｰﾌﾟﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2017/05/02 11:07:38                                            */
/****************************************************************************/
CREATE TABLE GE33 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , GROUP_ID     VARCHAR2 (  20 )                    NOT NULL            /*  20 ｸﾞﾙｰﾌﾟID */
 , ADDRESS      VARCHAR2 ( 256 )                    NOT NULL            /*  30 ｱﾄﾞﾚｽ    */
 , NAME_JA      VARCHAR2 ( 200 )                                        /*  40 名称     */
 , KBNAME       VARCHAR2 (   1 )                    NOT NULL            /*  50 名称区分 */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員 */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GE33S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GE33T00 
  BEFORE INSERT ON GE33
  FOR EACH ROW 
  BEGIN 
    SELECT GE33S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
